package core.entities.timemanager;

import core.api.models.timemanager.taskSchedule.scheduleInfos.AdvancedScheduleInfo;
import core.api.models.timemanager.taskSchedule.scheduleInfos.ScheduleInfo;
import core.api.models.timemanager.taskSchedule.scheduleInfos.ScheduleType;
import core.api.models.timemanager.taskgroup.TaskgroupEntityInfo;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import java.time.LocalDateTime;
import java.util.List;

@Entity
@DiscriminatorValue("1")
public class AdvancedTaskSchedule extends AbstractSchedule {

    private LocalDateTime scheduleStart;
    private LocalDateTime scheduleEnd;

    public AdvancedTaskSchedule(LocalDateTime scheduleStart, LocalDateTime scheduleEnd) {
        this.scheduleStart = scheduleStart;
        this.scheduleEnd = scheduleEnd;
    }

    public AdvancedTaskSchedule(Task task, LocalDateTime startTime, LocalDateTime stopTime, LocalDateTime scheduleStart, LocalDateTime scheduleEnd) {
        super(task, startTime, stopTime);
        this.scheduleStart = scheduleStart;
        this.scheduleEnd = scheduleEnd;
    }

    public AdvancedTaskSchedule(Task task, LocalDateTime startTime, LocalDateTime scheduleStart, LocalDateTime scheduleEnd) {
        super(task, startTime);
        this.scheduleStart = scheduleStart;
        this.scheduleEnd = scheduleEnd;
    }

    public AdvancedTaskSchedule(Task task, LocalDateTime scheduleStart, LocalDateTime scheduleEnd) {
        super(task);
        this.scheduleStart = scheduleStart;
        this.scheduleEnd = scheduleEnd;
    }

    public AdvancedTaskSchedule() {

    }

    public LocalDateTime getScheduleStart() {
        return scheduleStart;
    }

    public void setScheduleStart(LocalDateTime scheduleStart) {
        this.scheduleStart = scheduleStart;
    }

    public LocalDateTime getScheduleEnd() {
        return scheduleEnd;
    }

    public void setScheduleEnd(LocalDateTime scheduleEnd) {
        this.scheduleEnd = scheduleEnd;
    }

    @Override
    public ScheduleInfo toScheduleInfo() {
        int activeMinutes = calcActiveMinutes();
        List<TaskgroupEntityInfo> taskgroupEntityInfos = Taskgroup.getAncestorList(task.getTaskgroup()).stream().map(TaskgroupEntityInfo::new).toList();
        return new AdvancedScheduleInfo(scheduleID, ScheduleType.ADVANCED, startTime, stopTime, activeMinutes, task, taskgroupEntityInfos, scheduleStart, scheduleEnd);
    }

    @Override
    public boolean isMissed(LocalDateTime timeReference) {
        return startTime == null && scheduleEnd.toLocalDate().isBefore(timeReference.toLocalDate());
    }

    @Override
    public AbstractSchedule cloneSchedule() {
        return new AdvancedTaskSchedule(this.task, this.scheduleStart, this.scheduleEnd);
    }

    @Override
    public void shiftSchedule(long numberDays) {
        this.scheduleStart = this.scheduleStart.plusDays(numberDays);
        this.scheduleEnd = this.scheduleEnd.plusDays(numberDays);
    }
}
