import {Component, OnInit, ViewChild} from '@angular/core';
import {NavigationLink} from "../../navigation-link-list/navigation-link-list.component";
import * as moment from "moment";
import {ChangeContext, LabelType, Options} from "ngx-slider-v2";
import {
  ChartComponent,
  ApexAxisChartSeries,
  ApexChart,
  ApexXAxis,
  ApexTitleSubtitle, ChartType, ApexPlotOptions, ApexDataLabels
} from "ng-apexcharts";
import {timeInterval} from "rxjs";
import {FormControl} from "@angular/forms";
import {HistoryService, TaskgroupPathInfo, TaskgroupService} from "../../../api";
import {SimpleActivityDiagramComponent} from "./simple-activity-diagram/simple-activity-diagram.component";
import {HeatmapActivityComponent} from "./heatmap-activity/heatmap-activity.component";

export type ChartOptions = {
  series: ApexAxisChartSeries;
  chart: ApexChart;
  xaxis: ApexXAxis;
  title: ApexTitleSubtitle;
  plotOptions: ApexPlotOptions,
  colors: any,
  dataLabels: ApexDataLabels;
};
@Component({
  selector: 'app-taskgroup-activity',
  templateUrl: './taskgroup-activity.component.html',
  styleUrls: ['./taskgroup-activity.component.css']
})
export class TaskgroupActivityComponent implements OnInit{
  defaultNavigationLinkPath: NavigationLink[] = [
    {
      linkText: 'Dashboard',
      routerLink: ['/']
    },
    {
      linkText: 'Statistics',
      routerLink: []
    },
    {
      linkText: 'Taskgroup Activity',
      routerLink: ['/statistics/taskgroup-activity']
    }
  ];

  @ViewChild('simpleActivityDiagram') simpleActivityDiagram ?: SimpleActivityDiagramComponent
  @ViewChild('heatMap') heatMap ?: HeatmapActivityComponent

  selectedChartype: string = "bar";
  availableChartTypes: string[] = ["bar", "line", "area", "heatmap"]
  selectedTaskgroupPath: TaskgroupPathInfo | undefined
  taskgroupPaths: TaskgroupPathInfo[] = []

  ngOnInit() {
    this.taskgroupService.taskgroupsPathGet().subscribe({
      next: resp => {
        this.taskgroupPaths = resp;
      }
    })
  }

  constructor(private taskgroupService: TaskgroupService) {

  }

  onSelectTaskgroupPath() {
    if(this.simpleActivityDiagram != undefined) {
      this.simpleActivityDiagram.setSelectedTaskgroupPath(this.selectedTaskgroupPath!);
    }

    this.heatMap?.setSelectedTaskgroupPath(this.selectedTaskgroupPath!);
  }

  onSelectChartType() {
    if(this.simpleActivityDiagram != undefined) {
      this.simpleActivityDiagram.setSelectedChartType(this.selectedChartype);
    }
  }

}
